@@ -20,6 +20,7 @@ use serde::{Deserialize, Serialize};
 use std::convert::{TryFrom, TryInto};
 use std::error::Error;
 use std::fmt::Formatter;
+use tap::TapFallible;
 
 /// An internal container for the [`Combinator<T>`] type.
 #[derive(Debug, Clone, Serialize, Deserialize, PartialEq, Hash)]
@@ -167,7 +168,9 @@ where
     ///
     /// Any errors during the serialization process ([`toml::ser::Error`]).
     pub fn to_toml_string(&self) -> Result<String, toml::ser::Error> {
-        toml::to_string(&self)
+        toml::to_string(&self).tap_err(crate::tap_log_error_msg(
+            "failed to serialize combinator as TOML",
+        ))
     }
 }
 
@@ -271,9 +274,9 @@ mod tests {
         ];
 
         for (expected, input) in test_params {
+            let result: bool = input.clone().try_into().unwrap();
             assert_eq!(
-                expected,
-                input.clone().try_into().unwrap(),
+                result, expected,
                 "CombinatorInner did not AND items correctly: {:?}",
                 input
             );
@@ -346,6 +349,7 @@ mod tests {
         typ: CombinatorType,
     }
 
+    #[allow(clippy::too_many_lines)]
     static CASES: Lazy<Vec<TestItem>> = Lazy::new(|| {
         vec![
             // BEGIN: Empty combinators
@@ -484,9 +488,9 @@ mod tests {
     #[test]
     fn test_combinator() {
         for case in CASES.iter() {
+            let result: bool = case.combinator.clone().try_into().unwrap();
             assert_eq!(
-                case.evaluates_to,
-                case.combinator.clone().try_into().unwrap(),
+                result, case.evaluates_to,
                 "Combinator did not OR items correctly: {:?}",
                 case.combinator
             );
