@@ -1,14 +1,15 @@
 use std::fmt::Debug;
-use std::{fs, path::Path};
+use std::path::Path;
+use tokio::fs;
 
 pub use ::toml::*;
 use serde::de::DeserializeOwned;
 
-pub fn assert_file_contains_deserializable<T>(path: &Path, expected: &T)
+pub async fn assert_file_contains_deserializable<T>(path: &Path, expected: &T)
 where
     T: PartialEq + Debug + DeserializeOwned,
 {
-    let content_str = fs::read_to_string(path).unwrap_or_else(|err| {
+    let content_str = fs::read_to_string(path).await.unwrap_or_else(|err| {
         panic!(
             "failed to read from file at {}: {}",
             path.to_string_lossy(),
